# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['sqlalchemy_mptt-stubs']

package_data = \
{'': ['*']}

install_requires = \
['sqlalchemy-stubs>=0.3,<0.4', 'sqlalchemy_mptt>=0.2.5,<0.3.0']

setup_kwargs = {
    'name': 'sqlalchemy-mptt-stubs',
    'version': '0.0.3',
    'description': 'Stubs for sqlalchemy_mptt',
    'long_description': "sqlalchemy_mptt-stubs\n========================\n[![PyPI](https://img.shields.io/badge/pypi-0.0.3-orange.svg)](https://pypi.org/project/sqlalchemy-mptt-stubs/0.0.3) [![PyPI](https://img.shields.io/badge/python-3-blue.svg)](https://pypi.org/project/sqlalchemy-mptt-stubs/0.0.3)\n\nMost annotations generated by py pyannotate. It's still unstable.\n",
    'author': 'ssfdust',
    'author_email': 'ssfdust@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/ssfdust/sqlalchemy_mptt-stubs',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
